@@ -10,8 +10,8 @@ import itertools
 import logging
 import os.path
 import re
-import sys
 import shutil
+import sys
 from tempfile import NamedTemporaryFile
 import tempfile
 import time
@@ -19,8 +19,9 @@ import time
 import namedlist
 
 import wpull.backport.gzip
+from wpull.backport.logging import BraceMessage as __
+from wpull.bandwidth import BandwidthMeter
 from wpull.namevalue import NameValueRecord
-from wpull.network import BandwidthMeter
 import wpull.util
 import wpull.version
 from wpull.warc import WARCRecord
@@ -159,8 +160,8 @@ Args:
     cdx (bool): If True, a CDX file will be written.
     max_size (int): If provided, output files are named like
         ``name-00000.ext`` and the log file will be in ``name-meta.ext``.
-    move_to (str): If provided, completed WARC files and CDX files will be moved
-        to the given directory
+    move_to (str): If provided, completed WARC files and CDX files will be
+        moved to the given directory
     url_table (:class:`.database.URLTable`): If given, then ``revist``
         records will be written.
     software_string (str): The value for the ``software`` field in the
@@ -218,7 +219,7 @@ class WARCRecorder(BaseRecorder):
             self._prefix_filename, sequence_name, extension
         )
 
-        _logger.debug('WARC file at {0}'.format(self._warc_filename))
+        _logger.debug(__('WARC file at {0}', self._warc_filename))
 
         if not self._params.appending:
             wpull.util.truncate_file(self._warc_filename)
@@ -299,12 +300,12 @@ class WARCRecorder(BaseRecorder):
         assert self._params.move_to
 
         if os.path.isdir(self._params.move_to):
-            _logger.debug('Moved %s to %s.' % (self._warc_filename,
-                                               self._params.move_to))
+            _logger.debug('Moved %s to %s.', self._warc_filename,
+                          self._params.move_to)
             shutil.move(filename, self._params.move_to)
         else:
-            _logger.error('%s is not a directory; not moving %s.' %
-                          (self._params.move_to, filename))
+            _logger.error('%s is not a directory; not moving %s.',
+                          self._params.move_to, filename)
 
     def set_length_and_maybe_checksums(self, record, payload_offset=None):
         '''Set the content length and possibly the checksums.'''
@@ -320,8 +321,8 @@ class WARCRecorder(BaseRecorder):
         record.fields['WARC-Warcinfo-ID'] = self._warcinfo_record.fields[
             WARCRecord.WARC_RECORD_ID]
 
-        _logger.debug('Writing WARC record {0}.'.format(
-            record.fields['WARC-Type']))
+        _logger.debug(__('Writing WARC record {0}.',
+                         record.fields['WARC-Type']))
 
         if self._params.compress:
             open_func = wpull.backport.gzip.GzipFile
@@ -338,10 +339,10 @@ class WARCRecorder(BaseRecorder):
                 for data in record:
                     out_file.write(data)
         except (OSError, IOError) as error:
-            _logger.info(
-                _('Rolling back file {filename} to length {length}.')
-                .format(filename=self._warc_filename, length=before_offset)
-            )
+            _logger.info(__(
+                _('Rolling back file {filename} to length {length}.'),
+                filename=self._warc_filename, length=before_offset
+            ))
             with open(self._warc_filename, mode='wb') as out_file:
                 out_file.truncate(before_offset)
             raise error
@@ -423,7 +424,7 @@ class WARCRecorder(BaseRecorder):
 
         url = record.fields['WARC-Target-URI']
 
-        _logger.debug('Writing CDX record {0}.'.format(url))
+        _logger.debug(__('Writing CDX record {0}.', url))
 
         http_header = record.get_http_header()
 
